******
/*
do-file on SIAB data
job spells as of 30.06.
*/
******

set more off
capture log close

log using "$log\descrip_siab_7514.log", replace


*** load data
u persnr gebjahr erwstat teilzeit begorig endorig begepi endepi spell quelle frau tentgelt betnr using "$orig\SIAB_7514_v1.dta", clear
label language en

bysort persnr begepi (spell): gen byte level_2 = _n-1

g jahr=year(begepi)
drop if jahr==.

merge m:1 betnr jahr using "$orig\SIAB_7514_v1_bhp_basis_v1.dta ", keepusing(ao_kreis)
keep if _merge!=2
drop _merge

ren jahr year 

keep if level_2==0
drop if quelle!=1

*** Keep data only at the cut-off date 30th of June 
g datecut=mdy(6,30,year) 
format datecut %tdD_m_Y
keep if (begepi <= datecut & datecut<=endepi)

*Recode Wage to missing if equal to zero 
replace tentgelt =. if   tentgelt==0

**Set the wages over the highest SS limit to the maximum value
g temp=ao_kreis
g x=int(temp/1000)
recode x (12/16=1 "Est") (1/11=0 "West"), g(east)
lab var east "Est Region-Work"
drop temp x
count if east==. & tentgelt>0 & tentgelt<.
drop if east==. & tentgelt>0 & tentgelt<.

* Restrict to 1997-2014
keep if year>=1997 & year<=2014

*Set Limits for Top Coded Wages
gen east_d_up = .
gen east_d_low = .
gen west_d_up = .
gen west_d_low = .

replace east_d_up = 119.3458 if year==1997
replace east_d_up = 117.6687 if year==1998
replace east_d_up = 121.0279 if year==1999
replace east_d_up = 119.0237 if year==2000
replace east_d_up = 122.7101 if year==2001
replace east_d_up = 123.29 if year==2002
replace east_d_up = 139.73 if year==2003
replace east_d_up = 142.62 if year==2004
replace east_d_up = 144.66 if year==2005
replace east_d_up = 144.66 if year==2006
replace east_d_up = 149.59 if year==2007
replace east_d_up = 147.54 if year==2008
replace east_d_up = 149.59 if year==2009
replace east_d_up = 152.88 if year==2010
replace east_d_up = 160 if year==2011
replace east_d_up = 160 if year==2012
replace east_d_up = 163.33 if year==2013
replace east_d_up = 166.66 if year==2014

replace east_d_low = 8.743093  if year==1997
replace east_d_low = 8.743093 if year==1998
replace east_d_low = 10.58886 if year==1999
replace east_d_low = 10.56329 if year==2000
replace east_d_low = 10.58886 if year==2001
replace east_d_low = 10.68 if year==2002
replace east_d_low = 10.68 if year==2003
replace east_d_low = 13.11 if year==2004
replace east_d_low = 13.15 if year==2005
replace east_d_low = 13.15 if year==2006
replace east_d_low = 13.15 if year==2007
replace east_d_low = 13.11 if year==2008
replace east_d_low = 13.15 if year==2009
replace east_d_low = 13.15 if year==2010
replace east_d_low = 13.33 if year==2011
replace east_d_low = 13.33 if year==2012
replace east_d_low = 15 if year==2013
replace east_d_low = 15 if year==2014

replace west_d_up = 137.8392  if year==1997
replace west_d_up = 141.1984  if year==1998
replace west_d_up = 142.8806  if year==1999
replace west_d_up = 144.169  if year==2000
replace west_d_up = 146.2448 if year==2001
replace west_d_up = 147.95 if year==2002
replace west_d_up = 167.67 if year==2003
replace west_d_up = 168.85 if year==2004
replace west_d_up = 170.96 if year==2005
replace west_d_up = 172.6 if year==2006
replace west_d_up = 172.6 if year==2007
replace west_d_up = 173.77 if year==2008
replace west_d_up = 177.53 if year==2009
replace west_d_up = 180.8219 if year==2010
replace west_d_up = 183.33 if year==2011
replace west_d_up = 186.66 if year==2012
replace west_d_up = 193.33 if year==2013
replace west_d_up = 198.33 if year==2014

replace west_d_low =10.2514 if year==1997
replace west_d_low =10.42013 if year==1998
replace west_d_low =10.58886 if year==1999
replace west_d_low =10.56329 if year==2000
replace west_d_low =10.58886 if year==2001
replace west_d_low =10.68 if year==2002
replace west_d_low =10.68 if year==2003
replace west_d_low =13.11 if year==2004
replace west_d_low =13.15 if year==2005
replace west_d_low =13.15 if year==2006
replace west_d_low =13.15 if year==2007
replace west_d_low =13.11 if year==2008
replace west_d_low =13.15 if year==2009
replace west_d_low =13.15 if year==2010
replace west_d_low =13.33 if year==2011
replace west_d_low =13.33 if year==2012
replace west_d_low =15 if year==2013
replace west_d_low =15 if year==2014


*Tag observations above the upper censoring limit
replace tentgelt=round(tentgelt, 0.01)

g taghiwa=1 if tentgelt>=west_d_up & tentgelt<. & east==0 
replace taghiwa=1 if tentgelt>=east_d_up & tentgelt<. & east==1 & year>1990 

g taglowa=1 if tentgelt>0 & tentgelt<west_d_low & east==0 
replace taglowa=1 if tentgelt>0 &  tentgelt<east_d_low & east==1 & year>1990 

g taglowa2=1 if tentgelt>0 & tentgelt<2*west_d_low & east==0 
replace taglowa2=1 if tentgelt>0 &  tentgelt<2*east_d_low & east==1 & year>1990 

lab var taglowa "Tag for Wage lower SS Bounds"
lab var taghiwa "Tag for Wage higher SS Bounds"

g double tentgeltc=tentgelt
replace tentgeltc=west_d_up if taghiwa==1 & east==0
replace tentgeltc=east_d_up if taghiwa==1 & east==1

lab var tentgeltc "Daily Wage IEB-Censored with Bounds"
sum tentgelt*, d
drop east* west*

foreach var in erwstat teilzeit {
replace `var'=. if tentgeltc==.
}

bys persnr year: g dwagecut=tentgeltc
g age=year-gebjahr 

collapse (mean) age dwagecut erwstat teilzeit, by(persnr year) 


*** ad CPI values
gen cpi2005 = .
replace cpi2005 = 94.2139 if year==1997
replace cpi2005 = 94.7753 if year==1998
replace cpi2005 = 95.0755 if year==1999
replace cpi2005 = 94.6343 if year==2000
replace cpi2005 = 95.8443 if year==2001
replace cpi2005 = 97.1314 if year==2002
replace cpi2005 = 98.3139 if year==2003
replace cpi2005 = 99.3812 if year==2004
replace cpi2005 = 100 if year==2005
replace cpi2005 = 100.299 if year==2006
replace cpi2005 = 101.996 if year==2007
replace cpi2005 = 102.861 if year==2008
replace cpi2005 = 104.687 if year==2009
replace cpi2005 = 105.467 if year==2010
replace cpi2005 = 106.669 if year==2011
replace cpi2005 = 108.269 if year==2012
replace cpi2005 = 110.497 if year==2013
replace cpi2005 = 112.403 if year==2014

g marginal=1 if erwstat==109 | erwstat==209 
g ft=1 if teilzeit==0

g apprentice=1 if erwstat==102 | erwstat==121 | erwstat==122 |erwstat==141|erwstat==144

g real_dwage=dwagecut*100/cpi2005
g lreal_dwage=log(real_dwage)

keep if age>15 & age<66 & apprentice!=1 & marginal!=1

*Full time over time 
table year, c(count ft mean ft)
keep if ft==1

**Wage Quantiles by year: age 16-65

table year, c(count real_dwage p15 real_dwage p20 real_dwage p25 real_dwage p50 real_dwage)
table year, c(count real_dwage p75 real_dwage p80 real_dwage p85 real_dwage p90 real_dwage)

table year, c(count lreal_dwage p15 lreal_dwage p20 lreal_dwage p25 lreal_dwage p50 lreal_dwage)
table year, c(count lreal_dwage p75 lreal_dwage p80 lreal_dwage p85 lreal_dwage p90 lreal_dwage)

keep if age>19

**Wage Quantiles by year: age 20-65

table year, c(count real_dwage p15 real_dwage p85 real_dwage)
table year, c(count lreal_dwage p15 lreal_dwage p85 lreal_dwage)
 
keep if age>24

**Wage Quantiles by year: age 25-65

table year, c(count real_dwage p15 real_dwage p20 real_dwage p25 real_dwage p50 real_dwage)
table year, c(count real_dwage p75 real_dwage p80 real_dwage p85 real_dwage p90 real_dwage)

table year, c(count lreal_dwage p15 lreal_dwage p20 lreal_dwage p25 lreal_dwage p50 lreal_dwage)
table year, c(count lreal_dwage p75 lreal_dwage p80 lreal_dwage p85 lreal_dwage p90 lreal_dwage)

log close
