* Project: govt size and redistribution
*
* Author: Michele Battisti
*
* Description: Produces some very basic tables and charts
*
* Date created: April 8, 2014
* Last modified: January 31, 2015
*
* Input: cleaned data

clear 
set more off
set linesize 255
capture log close

* Use relative paths from master.do
* Log file
log using $log\03.smcl, replace

* Open and save (as Stata) OECD data with highest marginal tax rates
insheet using $orig/oecdtoprate.csv, comma
save $data/tax.dta, replace

* Open swiid dataset and see whether there are things that I should do
use $data\02.dta, clear

* Generate csv dataset with post government gini in 1995 and 2012
keep if year==2012 |year==1995


* Generate relative Gini coefficient
use $data\02.dta, clear
gen giniratio=gini_net/gini_market


* CROSS SECTION ANALYSIS
* only keep last year of each country
gsort country -year
duplicates drop country, force

* Merge in data with highest marginal tax rate
merge 1:1 countrystring using $data/tax

* Correlation
reg giniratio govexpp
reg gini_net govexpp
reg gini_net gini_market govexpp

* Save so thjat I can go back to it
save $data\03.dta, replace

* Simple chart with size of government on the 
* horizontal axis and gini ratio on the vertical axis
* Try with relatively large countries
* keep if pop>20
* Keep relatively large countries by GDP
keep if gdpcurrentusd>100 & govexpp>30
*keep if gdpcurrentusd>500
la var giniratio "Gini after tax / Gini before tax"
reg giniratio govexpp
predict hat
la var hat "Linear Prediction"
gen pos = 3
*replace pos = 9 if giniratio < hat
*replace pos = 9 if destination == "France"

twoway ///
	(scatter giniratio govexpp, mlabel(country) mlabv(pos) mlabcolor(black)) ///
	(line hat govexpp, sort lwidth(medthick) lcolor(cranberry)) ///
	, legend(off) ///
	text(0.9 35 "{&beta} = `=string(`=_b[govexpp]',"%8.3f")'", placement(right) size(small) color(cranberry)) ///
	text(0.88 35 "R squared = `=string(`=e(r2)',"%8.2f")'" , placement(right) size(small) color(cranberry)) ///
	   legend(nobox region(lcolor(white))) scheme(s2color) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(ltblue)) ///
	  ytitle("Gini after taxes / Gini before taxes") ///
	  note("Source: SWIID dataset and IMF World Economic Outlook data, 2012", span)
graph export $output\1.emf, replace

* Only keep variables that I need
keep country giniratio govexpp
outsheet using $output\1.xls, replace

* get Gini before and Gini after tax across countries
use $data\03.dta, clear
keep if gdpcurrentusd>100 & govexpp>30
* Drop a few more to save space
drop if country==13 | country==4 | country==37 | country==44 | country==64 | country==56 | ///
		country==70 | country==116 | country==117 | country==119 | country==120 | country==151 | ///
		country==156 | country==157 | country==129 
graph dot gini_market gini_net, ///
  over(country, sort(1)) ///
  legend(label(1 "Market income") label(2 "Net income")) ///
  legend(nobox region(lcolor(white))) scheme(s2color) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(ltblue)) ///
  note("Source: SWIID dataset and IMF World Economic Outlook data, 2012", span)
graph export $output\4.emf, replace

graph dot gini_market gini_net, ///
  over(country, sort(2)) ///
  legend(label(1 "Market income") label(2 "Net income")) ///
  legend(nobox region(lcolor(white))) scheme(s2color) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(ltblue)) ///
  note("Source: SWIID dataset and IMF World Economic Outlook data, 2012", span)
graph export $output\5.emf, replace

* Keep right variables, export dataset
keep country gini_market gini_net
outsheet using $output\5.xls, replace

* Marginal tax rates and redistribution
use $data\03.dta, clear
drop if countrystring=="Poland"
drop if countrystring=="Israel"
*keep if gdpcurrentusd>500
la var giniratio "Gini after tax / Gini before tax"
la var tax "Highest marginal tax rate (2012)"
reg giniratio tax
predict hat
la var hat "Linear Prediction"
gen pos = 3
replace pos = 9 if countrystring == "Denmark"
replace pos = 9 if countrystring == "Netherlands"
replace pos = 12 if countrystring == "France"

twoway ///
	(scatter giniratio tax, mlabel(country) mlabv(pos) mlabcolor(black)) ///
	(line hat tax, sort lwidth(medthick) lcolor(cranberry)) ///
	, legend(off) ///
	text(0.87 0.4 "{&beta} = `=string(`=_b[tax]',"%8.3f")'", placement(right) size(small) color(cranberry)) ///
	text(0.84 0.4 "R squared = `=string(`=e(r2)',"%8.2f")'" , placement(right) size(small) color(cranberry)) ///
	   legend(nobox region(lcolor(white))) scheme(s2color) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(ltblue)) ///
	  ytitle("Gini after taxes / Gini before taxes") ylabel(0.5 (0.1) 1) yscale(range(0.5 1)) ///
	  note("Source: SWIID dataset and OECD Tax Database. Selected OECD countries, 2012", span)
graph export $output\6.emf, replace

* Keep variables and save
keep country giniratio tax
outsheet using $output\6.xls, replace
	
* Close log
log close
